@@ -1,5 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -885,10 +886,10 @@ sub Bounce {
     };
 
     # check needed stuff
-    for (qw(From To Email)) {
-        if ( !$Param{$_} ) {
+    for my $Needed (qw(From To Email)) {
+        if ( !$Param{$Needed} ) {
             return $SendError->(
-                ErrorMessage => "Need $_!",
+                ErrorMessage => "Need $Needed!",
             );
         }
     }
@@ -914,8 +915,8 @@ sub Bounce {
     $HeaderObject->replace( 'Resent-Date',       $DateTimeObject->ToEmailTimeStamp() );
     my $Body         = $EmailObject->body();
     my $BodyAsString = '';
-    for ( @{$Body} ) {
-        $BodyAsString .= $_ . "\n";
+    for my $String ( @{$Body} ) {
+        $BodyAsString .= $String . "\n";
     }
     my $HeaderAsString = $HeaderObject->as_string();
     my $OldMessageID   = $HeaderObject->get('Message-ID') || '??';
